## ----, message=FALSE-----------------------------------------------------
require(mosaic)
require(tigerstats)

## ----, eval=FALSE--------------------------------------------------------
#  data(m111survey)
#  View(m111survey)
#  help(m111survey)

## ------------------------------------------------------------------------
str(m111survey)

## ------------------------------------------------------------------------
favstats(~fastest, data = m111survey)

## ------------------------------------------------------------------------
favstats(fastest~sex, data = m111survey)

## ------------------------------------------------------------------------
favstats(~fastest, data=m111survey)[c("mean","sd")]

## ------------------------------------------------------------------------
favstats(fastest~sex, data = m111survey)[c("sex","mean","sd")]

